==> haskell-test-framework-smallcheck-0.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-38XbbuAx5mVCzDYtEboQkn
key: test-framework-smallcheck-0.2-38XbbuAx5mVCzDYtEboQkn
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: f75d690fc29d659e41a8ea1bbc99aeec
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-38XbbuAx5mVCzDYtEboQkn
depends:
    base-4.12.0.0 smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    test-framework-0.8.2.0-6VNxYg0rOQvC6zSsMyV1CA transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-1khA89TOUY1InmuVcEkFkg
key: test-framework-smallcheck-0.2-1khA89TOUY1InmuVcEkFkg
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: d0ca7ca058e992a096a90f54791fdad7
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-1khA89TOUY1InmuVcEkFkg
depends:
    base-4.12.0.0 smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
